==> evita_external_api_graphql-2024.8.4-sources.jar: io/evitadb/externalApi/graphql/api/catalog/schemaApi/resolver/dataFetcher/AssociatedDataSchemasDataFetcher.java <==
/*
 *
 *                         _ _        ____  ____
 *               _____   _(_) |_ __ _|  _ \| __ )
 *              / _ \ \ / / | __/ _` | | | |  _ \
 *             |  __/\ V /| | || (_| | |_| | |_) |
 *              \___| \_/ |_|\__\__,_|____/|____/
 *
 *   Copyright (c) 2023
 *
 *   Licensed under the Business Source License, Version 1.1 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *   https://github.com/FgForrest/evitaDB/blob/master/LICENSE
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */

package io.evitadb.externalApi.graphql.api.catalog.schemaApi.resolver.dataFetcher;

import graphql.schema.DataFetcher;
import graphql.schema.DataFetchingEnvironment;
import io.evitadb.api.requestResponse.schema.EntitySchemaContract;

import javax.annotation.Nonnull;

/**
 * Passes {@link EntitySchemaContract} down to resolving individual {@link io.evitadb.api.requestResponse.schema.AssociatedDataSchemaContract}s.
 *
 * @author Lukáš Hornych, FG Forrest a.s. (c) 2022
 */
public class AssociatedDataSchemasDataFetcher implements DataFetcher<EntitySchemaContract> {

	@Nonnull
	@Override
	public EntitySchemaContract get(@Nonnull DataFetchingEnvironment environment) throws Exception {
		return environment.getSource();
	}
}

==> evita_external_api_graphql-2024.12.11-sources.jar: io/evitadb/externalApi/graphql/api/catalog/schemaApi/resolver/dataFetcher/AssociatedDataSchemasDataFetcher.java <==
/*
 *
 *                         _ _        ____  ____
 *               _____   _(_) |_ __ _|  _ \| __ )
 *              / _ \ \ / / | __/ _` | | | |  _ \
 *             |  __/\ V /| | || (_| | |_| | |_) |
 *              \___| \_/ |_|\__\__,_|____/|____/
 *
 *   Copyright (c) 2023-2024
 *
 *   Licensed under the Business Source License, Version 1.1 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *   https://github.com/FgForrest/evitaDB/blob/master/LICENSE
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */

package io.evitadb.externalApi.graphql.api.catalog.schemaApi.resolver.dataFetcher;

import graphql.schema.DataFetcher;
import graphql.schema.DataFetchingEnvironment;
import io.evitadb.api.requestResponse.schema.EntitySchemaContract;
import lombok.AccessLevel;
import lombok.NoArgsConstructor;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

/**
 * Passes {@link EntitySchemaContract} down to resolving individual {@link io.evitadb.api.requestResponse.schema.AssociatedDataSchemaContract}s.
 *
 * @author Lukáš Hornych, FG Forrest a.s. (c) 2022
 */
@NoArgsConstructor(access = AccessLevel.PRIVATE)
public class AssociatedDataSchemasDataFetcher implements DataFetcher<EntitySchemaContract> {

	@Nullable
	private static AssociatedDataSchemasDataFetcher INSTANCE;

	@Nonnull
	public static AssociatedDataSchemasDataFetcher getInstance() {
		if (INSTANCE == null) {
			INSTANCE = new AssociatedDataSchemasDataFetcher();
		}
		return INSTANCE;
	}

	@Nonnull
	@Override
	public EntitySchemaContract get(@Nonnull DataFetchingEnvironment environment) throws Exception {
		return environment.getSource();
	}
}
